@@ -1,7 +1,7 @@
 import base64
 from unsafe.utils.encrypt import Encryptor
 from unsafe.utils.strings import wordlist
-
+from typing import Optional, Union
 
 class Decrypter:
     """
@@ -9,34 +9,11 @@ class Decrypter:
     """
 
     def __init__(self) -> None:
-        pass
+        ...
 
-    def text_decrypt(self, hash: str | bytes, word: str | list = wordlist, encode: str | None = None, hash_method: str = "MD5", **kwargs) -> str | bytes:
+    def text_decrypt(self, hash: Optional[str | bytes], word: Optional[str | list] = wordlist, encode: Optional[str] = None, hash_method: str = "MD5", **kwargs) -> Union[str, bytes]:
         """
         function to return encrypted string.
-        
-        args:
-
-            * hash: your hash to decrypt
-            
-            `text_decrypt(hash = "2fe89d7b42be7dedb4304ac249fbde9c")`
-            
-            * encode: your choose to encode word (default=None)
-            
-            `text_decrypt(hash = "2fe89d7b42be7dedb4304ac249fbde9c", encode = "UTF-8")`
-            
-            * hash_method: your chosen hash method(default=md5)
-            
-            `text_decrypt(hash = "2fe89d7b42be7dedb4304ac249fbde9c", hash_method = "SHA1")`
-            
-            `Available Hash Method's : ['MD5', 'SHA1', 'SHA224', 'SHA256', 'SHA384', 'SHA512', 'SHA3-224', 'SHA3-256', 'SHA3-384', 'SHA3-512', 'SHAKE128', 'SHAKE256', 'BASE16', 'BASE32', 'BASE64', 'BASE85', 'ASCII85', 'CAESAR']`
-
-            * count: for 'CAESAR' method(default = 1)
-            
-            defalut count for shake method's based on len of hash
-            
-            
-            `text_decrypt(hash = "votbgf", hash_method = 'CAESAR', count = 4)`
         """
 
         hash_method = hash_method.lower()
@@ -243,12 +220,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "MD5")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="MD5")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha1':
                 for i in word:
@@ -256,12 +233,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA1")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA1")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha256':
                 for i in word:
@@ -269,12 +246,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA256")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA256")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha224':
                 for i in word:
@@ -282,12 +259,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA224")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA224")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha384':
                 for i in word:
@@ -295,12 +272,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA384")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA384")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha512':
                 for i in word:
@@ -308,12 +285,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA512")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA512")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha3-224':
                 for i in word:
@@ -321,12 +298,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA3-224")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA3-224")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha3-256':
                 for i in word:
@@ -334,12 +311,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA3-256")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA3-256")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha3-384':
                 for i in word:
@@ -347,12 +324,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA3-384")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA3-384")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'sha3-512':
                 for i in word:
@@ -360,12 +337,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(i, encode, "SHA3-512")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=i, hash_method="SHA3-512")) == hash:
                             return i
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'shake128':
                 for i in word:
@@ -373,12 +350,12 @@ class Decrypter:
                         if str(encryptor.text_encrypt(word, encode, "SHAKE128", count=str(count))) == hash:
                             return word
                         else:
-                            pass
+                            ...
                     else:
                         if str(encryptor.text_encrypt(words=word, hash_method="SHAKE128", count=str(count))) == hash:
                             return word
                         else:
-                            pass
+                            ...
                 return ""
             elif hash_method == 'shake256':
                 if encode:
